==> lclint_2.1b-1.tar.gz: lclint-2.1b/src/Headers/sortSet.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994, 1995, 1996.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. This code may not be re-distributed or modified
**        without permission from MIT (contact 
**        lclint-request@larch.lcs.mit.edu.)  
**
**        Modification and re-distribution are encouraged,
**        but we want to keep track of changes and
**        distribution sites.
*/
/*
** sortSet.h
**
** based on set_template.h
*/

# ifndef SORTSET_H
# define SORTSET_H

abst_typedef /*@null@*/ struct _sortSet
{
  int entries;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ sort  *elements;
} *sortSet ;

/*@iter sortSet_elements(sef sortSet s, yield sort el); @*/
# define sortSet_elements(x, m_el) \
    if (sortSet_isDefined (x)) { int m_ind; \
       for (m_ind = 0 ; m_ind < (x)->entries; m_ind++) \
         { sort m_el = (x)->elements[m_ind];

# define end_sortSet_elements }}

/*@constant null sortSet sortSet_undefined; @*/
# define sortSet_undefined ((sortSet) NULL)
extern /*@falsenull@*/ bool sortSet_isDefined (sortSet s) /*@*/ ;
# define sortSet_isDefined(s) ((s) != sortSet_undefined)

extern int sortSet_size (/*@sef@*/ sortSet s);
# define sortSet_size(s) (sortSet_isDefined (s) ? (s)->entries : 0)

extern /*@only@*/ sortSet sortSet_new(void);
extern bool sortSet_insert (sortSet s, sort el);
extern bool sortSet_member (sortSet s, sort el);
extern /*@only@*/ cstring sortSet_unparse (sortSet s);
extern /*@only@*/ cstring sortSet_unparseClean (sortSet s);
extern /*@only@*/ cstring sortSet_unparseOr (sortSet s);
extern void sortSet_free (/*@only@*/ sortSet s);
extern sort sortSet_choose (sortSet s);
extern /*@only@*/ sortSet sortSet_copy (sortSet s);

/*@constant int sortSetBASESIZE;@*/
# define sortSetBASESIZE MIDBASESIZE

# else
# error "Multiple include"
# endif

==> lclint_2.4b.orig.tar.gz: lclint-2.4b/src/Headers/sortSet.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994-1998.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. Works derived from this code are not distributed for
**        commercial gain without explicit permission from MIT 
**        (for permission contact lclint-request@sds.lcs.mit.edu).
*/
/*
** sortSet.h
**
** based on set_template.h
*/

# ifndef SORTSET_H
# define SORTSET_H

abst_typedef /*@null@*/ struct _sortSet
{
  int entries;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ sort  *elements;
} *sortSet ;

/*@iter sortSet_elements(sef sortSet s, yield sort el); @*/
# define sortSet_elements(x, m_el) \
    if (sortSet_isDefined (x)) { int m_ind; \
       for (m_ind = 0 ; m_ind < (x)->entries; m_ind++) \
         { sort m_el = (x)->elements[m_ind];

# define end_sortSet_elements }}

/*@constant null sortSet sortSet_undefined; @*/
# define sortSet_undefined ((sortSet) NULL)
extern /*@falsenull@*/ bool sortSet_isDefined (sortSet p_s) /*@*/ ;
# define sortSet_isDefined(s) ((s) != sortSet_undefined)

extern int sortSet_size (/*@sef@*/ sortSet p_s);
# define sortSet_size(s) (sortSet_isDefined (s) ? (s)->entries : 0)

extern /*@only@*/ sortSet sortSet_new(void);
extern bool sortSet_insert (sortSet p_s, sort p_el);
extern bool sortSet_member (sortSet p_s, sort p_el);
extern /*@only@*/ cstring sortSet_unparse (sortSet p_s);
extern /*@only@*/ cstring sortSet_unparseClean (sortSet p_s);
extern /*@only@*/ cstring sortSet_unparseOr (sortSet p_s);
extern void sortSet_free (/*@only@*/ sortSet p_s);
extern sort sortSet_choose (sortSet p_s);
extern /*@only@*/ sortSet sortSet_copy (sortSet p_s);

/*@constant int sortSetBASESIZE;@*/
# define sortSetBASESIZE MIDBASESIZE

# else
# error "Multiple include"
# endif
